[−][src]Struct browser_window::application::ApplicationHandle
A thread-unsafe application handle. Often provided by for Browser Window.
Implementations
impl ApplicationHandle[src]
pub fn exit(&self, exit_code: i32)[src]
Causes the Runtime to terminate.
The Runtime's Runtime::run or spawn command will return the exit code provided.
This will mean that not all tasks might complete.
If you were awaiting
pub fn into_threaded(self) -> ApplicationHandleThreaded[src]
Note: Only available with feature threadsafe enabled.
Transforms this application handle into a thread-safe version of it.
pub fn spawn<F>(&self, future: F) where
F: Future<Output = ()> + 'static, [src]
F: Future<Output = ()> + 'static,
Spawns the given future, executing it on the GUI thread somewhere in the near future.