[][src]Struct browser_window::Browser

pub struct Browser { /* fields omitted */ }

A thread-unsafe handle to a browser window

Implementations

impl Browser[src]

pub fn app(&self) -> Application[src]

Returns the application handle associated with this browser window.

pub fn close(self)[src]

Closes the browser.

pub async fn eval_js<'_, '_>(
    &'_ self,
    js: &'_ str
) -> Result<String, JsEvaluationError>
[src]

Executes the given javascript code and returns the output as a string. If you don't need the result, see exec_js.

pub fn exec_js(&self, js: &str)[src]

Executes the given javascript code without waiting on it to finish.

pub fn navigate(&self, url: &str) -> Result<(), Box<dyn Error + Send>>[src]

Causes the browser to navigate to the given url.