[][src]Struct browser_window::BrowserBuilder

pub struct BrowserBuilder { /* fields omitted */ }

Used to create a Browser or BrowserThreaded instance.

Implementations

impl BrowserBuilder[src]

pub fn borders(self, value: bool) -> Self[src]

Sets whether or not the window has borders. Default is true.

pub fn handler<H>(self, handler: H) -> Self where
    H: FnMut(Browser, &str, &[&str]) + Send + 'static, 
[src]

Configure a closure that can be invoked from within JavaScript. The closure's second parameter specifies a command name. The closure's third parameter specifies an array of string arguments.

pub fn minimizable(self, value: bool) -> Self[src]

Sets whether or not the window has a minimize button on the title bar Default is true

pub fn parent<B>(self, bw: &B) -> Self where
    B: Deref<Target = BrowserHandle>, 
[src]

Configure a parent window. When a parent window closes, this browser window will close as well. This could be a reference to a Browser or BrowserThreaded handle.

pub fn new(source: Source) -> Self[src]

Creates an instance of a browser window builder.

Arguments

  • source - The content that will be displayed in the browser window.

pub fn title<S: Into<String>>(self, title: S) -> Self[src]

Sets the title of the window

Arguments

  • title - The text that will be displayed in the title bar

pub fn width(self, width: u32) -> Self[src]

Sets the width that the browser window will be created with initially

Arguments

  • width - Width in pixels

pub fn height(self, height: u32) -> Self[src]

Sets the height that the browser window will be created with initially

Arguments

  • height - Height in pixels

pub fn resizable(self, resizable: bool) -> Self[src]

Sets whether or not the window will be resizable Default is true

pub async fn build(self, app: Application) -> Browser[src]

Creates the browser window.

Arguments

  • app - An application handle that this browser window can spawn into

pub async fn build_threaded(self, app: ApplicationThreaded) -> BrowserThreaded[src]

Same as build, but gives back a browser handle that is thread-safe.

Arguments

  • app - An thread-safe application handle.