[−][src]Struct browser_window::BrowserThreaded
A thread-safe handle to a browser window. It allows you to dispatch code to the GUI thread.
Implementations
impl BrowserThreaded[src]
pub fn app(&self) -> ApplicationThreaded[src]
The thread-safe application handle associated with this browser window.
pub fn close(self)[src]
Closes the browser.
pub fn delegate<'a, F, R>(&self, func: F) -> BrowserDelegateFuture<'a, R> where
F: FnOnce(Browser) -> R + Send + 'a,
R: Send, [src]
F: FnOnce(Browser) -> R + Send + 'a,
R: Send,
Executes the given closure within the GUI thread, and return the value that the closure returned. Keep in mind that in multi-threaded environments, it is generally a good idea to use a Box return type, or use something else to put the value on the heap when dealing with large types.
pub fn dispatch<'a, F>(&self, func: F) where
F: FnOnce(Browser) + Send + 'a, [src]
F: FnOnce(Browser) + Send + 'a,
Executes the given close on the GUI thread.
pub async fn eval_js<'_, '_>(
&'_ self,
js: &'_ str
) -> Result<String, JsEvaluationError>[src]
&'_ self,
js: &'_ str
) -> Result<String, JsEvaluationError>
Executes the given javascript code, and returns the resulting output as a string when done.
pub async fn navigate<'_, '_>(
&'_ self,
url: &'_ str
) -> Result<(), Box<dyn Error + Send>>[src]
&'_ self,
url: &'_ str
) -> Result<(), Box<dyn Error + Send>>
Causes the browser to navigate to the given url.