[][src]Struct browser_window::window::WindowBuilder

pub struct WindowBuilder { /* fields omitted */ }

Exposes functionality related to constructing a window.

Implementations

impl WindowBuilder[src]

pub fn borders(&mut self, value: bool) -> &mut Self[src]

Sets whether or not the window has borders. Default is true.

pub fn height(&mut self, height: u32) -> &mut Self[src]

Sets the height that the browser window will be created with initially

pub fn minimizable(&mut self, value: bool) -> &mut Self[src]

Sets whether or not the window has a minimize button on the title bar Default is true

pub fn parent<W>(&mut self, bw: &W) -> &mut Self where
    W: OwnedWindow
[src]

Sets the opacity of the window. An opacity of 255 is the default and means the window is fully visible. An lower opacity means the window will be transparent. Configure a parent window. When a parent window closes, this browser window will close as well. This could be a reference to a Browser or BrowserThreaded handle.

pub fn new() -> Self[src]

pub fn size(&mut self, width: u32, height: u32) -> &mut Self[src]

Sets the width and height of the browser window

pub fn title<S: Into<String>>(&mut self, title: S) -> &mut Self[src]

Sets the title of the window.

pub fn width(&mut self, width: u32) -> &mut Self[src]

Sets the width that the browser window will be created with initially.

pub fn resizable(&mut self, resizable: bool) -> &mut Self[src]

Sets whether or not the window will be resizable. Default is true.