[−][src]Struct browser_window::browser::BrowserWindowHandle
This is a handle to an existing browser window.
Implementations
impl BrowserWindowHandle[src]
pub fn app(&self) -> ApplicationHandle[src]
Returns the application handle associated with this browser window.
pub async fn eval_js<'_, '_>(
&'_ self,
js: &'_ str
) -> Result<String, JsEvaluationError>[src]
&'_ self,
js: &'_ str
) -> Result<String, JsEvaluationError>
Executes the given javascript code and returns the output as a string.
If you don't need the result, see exec_js.
pub fn exec_js(&self, js: &str)[src]
Executes the given javascript code without waiting on it to finish.
pub fn navigate(&self, url: &str)[src]
Causes the browser to navigate to the given url.
pub fn window(&self) -> WindowHandle[src]
Methods from Deref<Target = WindowHandle>
pub fn content_dimensions<'a>(&'a self) -> ContentDimensions<'_>[src]
pub fn opacity<'a>(&'a self) -> Opacity<'_>[src]
pub fn position<'a>(&'a self) -> Position<'_>[src]
pub fn title<'a>(&'a self) -> Title<'_>[src]
pub fn window_dimensions<'a>(&'a self) -> WindowDimensions<'_>[src]
pub fn hide(&self)[src]
Make the window invisible to the user.
pub fn show(&self)[src]
Make the window visible to the user.