pub unsafe auto trait Send { }Expand description
Types that can be transferred across thread boundaries.
This trait is automatically implemented when the compiler determines it’s appropriate.
An example of a non-Send type is the reference-counting pointer
rc::Rc. If two threads attempt to clone Rcs that point to the same
reference-counted value, they might try to update the reference count at the
same time, which is undefined behavior because Rc doesn’t use atomic
operations. Its cousin sync::Arc does use atomic operations (incurring
some overhead) and thus is Send.
See the Nomicon and the Sync trait for more details.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl !Send for Args
impl !Send for ArgsOs
impl !Send for Arguments<'_>
impl !Send for LocalWaker
impl Send for ApplicationHandleThreaded
threadsafe only.impl Send for Bytes<'_>
impl Send for alloc::string::Drain<'_>
impl Send for Location<'_>
impl Send for TypeId
impl Send for Waker
impl<'a, O, H, R> Send for DelegateFuture<'a, O, H, R>where
R: Send,
Safety
DelegateFuture by itself is not send.
This is because we keep a handle H, which is not necessarily Send.
However, because the closure only executes on the GUI thread,
and because the handle is only provided to the closure that will be
executed on the GUI thread, this should be fine.
impl<'a, R> Send for DelegateFutureFuture<'a, R>where
R: Send,
Safety
DelegateFutureFuture by itself is not send.
This is because of ApplicationHandle.
However, because the closure only executes on the GUI thread,
and because this handle that is provided to the closure is something that
will only be sent with the closure to the GUI thread, this should be fine.
impl<'a> Send for IoSlice<'a>
impl<'a> Send for IoSliceMut<'a>
impl<Dyn> Send for DynMetadata<Dyn>where
Dyn: ?Sized,
impl<T, A> !Send for Rc<T, A>
impl<T, A> !Send for UniqueRc<T, A>
impl<T, A> !Send for alloc::rc::Weak<T, A>
impl<T, A> Send for Arc<T, A>
impl<T, A> Send for Cursor<'_, T, A>
impl<T, A> Send for CursorMut<'_, T, A>
impl<T, A> Send for alloc::collections::vec_deque::drain::Drain<'_, T, A>
impl<T, A> Send for alloc::vec::drain::Drain<'_, T, A>
impl<T, A> Send for IntoIter<T, A>
impl<T, A> Send for LinkedList<T, A>
impl<T, A> Send for UniqueArc<T, A>
impl<T, A> Send for alloc::sync::Weak<T, A>
impl<T> !Send for *const Twhere
T: ?Sized,
impl<T> !Send for *mut Twhere
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::poison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::mutex::MutexGuard<'_, T>where
T: ?Sized,
A MutexGuard is not Send to maximize platform portability.
On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to
release mutex locks on the same thread they were acquired.
For this reason, MutexGuard must not implement Send to prevent it being dropped from
another thread.
impl<T> !Send for std::sync::poison::mutex::MutexGuard<'_, T>where
T: ?Sized,
A MutexGuard is not Send to maximize platform portability.
On platforms that use POSIX threads (commonly referred to as pthreads) there is a requirement to
release mutex locks on the same thread they were acquired.
For this reason, MutexGuard must not implement Send to prevent it being dropped from
another thread.
impl<T> !Send for NonNull<T>where
T: ?Sized,
NonNull pointers are not Send because the data they reference may be aliased.
impl<T> !Send for ReentrantLockGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::poison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> !Send for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> Send for &T
impl<T> Send for Atomic<T>where
T: AtomicPrimitive,
impl<T> Send for Cell<T>
impl<T> Send for ChunksExactMut<'_, T>where
T: Send,
impl<T> Send for ChunksMut<'_, T>where
T: Send,
impl<T> Send for core::slice::iter::Iter<'_, T>where
T: Sync,
impl<T> Send for alloc::collections::linked_list::Iter<'_, T>where
T: Sync,
impl<T> Send for core::slice::iter::IterMut<'_, T>where
T: Send,
impl<T> Send for alloc::collections::linked_list::IterMut<'_, T>where
T: Send,
impl<T> Send for JoinHandle<T>
impl<T> Send for std::sync::nonpoison::mutex::Mutex<T>
T must be Send for a Mutex to be Send because it is possible to acquire
the owned T from the Mutex via into_inner.
impl<T> Send for std::sync::poison::mutex::Mutex<T>
T must be Send for a Mutex to be Send because it is possible to acquire
the owned T from the Mutex via into_inner.
impl<T> Send for NonZero<T>where
T: ZeroablePrimitive + Send,
impl<T> Send for OnceLock<T>where
T: Send,
impl<T> Send for RChunksExactMut<'_, T>where
T: Send,
impl<T> Send for RChunksMut<'_, T>where
T: Send,
impl<T> Send for std::sync::mpmc::Receiver<T>where
T: Send,
impl<T> Send for std::sync::mpsc::Receiver<T>where
T: Send,
impl<T> Send for ReentrantLock<T>
impl<T> Send for RefCell<T>
impl<T> Send for std::sync::nonpoison::rwlock::RwLock<T>
impl<T> Send for std::sync::poison::rwlock::RwLock<T>
impl<T> Send for std::sync::mpmc::Sender<T>where
T: Send,
impl<T> Send for std::sync::mpsc::Sender<T>where
T: Send,
impl<T> Send for SyncSender<T>where
T: Send,
impl<T> Send for ThinBox<T>
ThinBox<T> is Send if T is Send because the data is owned.