[−][src]Struct browser_window::ApplicationThreaded
A thread-safe application handle. This handle also allows you to dispatch code to be executed on the GUI thread.
Implementations
impl ApplicationThreaded[src]
pub fn delegate<'a, F, R>(&self, func: F) -> ApplicationDelegateFuture<'a, R> where
F: FnOnce(Application) -> R + Send + 'a,
R: Send, [src]
F: FnOnce(Application) -> R + Send + 'a,
R: Send,
Executes the given closure on the GUI thread, and gives back the result when done. Keep in mind that in multi-threaded environments, it is generally a good idea to use a Box return type, or use something else to put the value on the heap when dealing with large types.
pub fn dispatch<'a, F>(&self, func: F) where
F: FnOnce(Application) + Send + 'a, [src]
F: FnOnce(Application) + Send + 'a,
Executes the given closure on the GUI thread.
pub fn exit(&self, exit_code: i32)[src]
Signals the runtime to exit.
This will cause Runtime::run to stop and return the provided exit code.